@@ -27,8 +27,6 @@ namespace QAccessibleClient {
     class AccessibleObject;
 }
 
-uint qHash(const QAccessibleClient::AccessibleObject& object);
-
 #include <qlist.h>
 #include <QSharedPointer>
 #include <qaction.h>
@@ -40,9 +38,11 @@ namespace QAccessibleClient {
 class AccessibleObjectPrivate;
 class RegistryPrivate;
 
+
 #ifndef QT_NO_DEBUG_STREAM
-QACCESSIBILITYCLIENT_EXPORT QDebug operator<<(QDebug, const AccessibleObject &);
+    QACCESSIBILITYCLIENT_EXPORT QDebug operator<<(QDebug, const AccessibleObject &);
 #endif
+
 /**
     This class represents an accessible object.
 
@@ -185,6 +185,20 @@ public:
 //    LayeredPane    = 0x00000080,
     };
 
+    /**
+        \brief The TextBoundaries enum represents the different boundaries when
+        asking for text at a certain offset.
+     */
+    enum TextBoundary {
+        CharBoundary,
+        WordStartBoundary,
+        WordEndBoundary,
+        SentenceStartBoundary,
+        SentenceEndBoundary,
+        LineStartBoundary,
+        LineEndBoundary
+    };
+
     /**
         \brief Construct an invalid AccessibleObject.
      */
@@ -436,6 +450,23 @@ public:
     */
     QString text(int startOffset = 0, int endOffset = -1) const;
 
+    /**
+        \brief Returns the text of the TextInterface by boundary.
+
+        Especially for larger text fields it may be more performant and easier to
+        query the text at a certain position instead of the full text.
+
+        For example the line where the cursor is currently can be retrieved with this function
+        in a convenient way.
+
+        \param offset is the position of the requested text.
+        \param startOffset returns the beginning of the offset, for example the start of the line when
+            asking for line boundaries.
+        \param endOffset returns the end of the text section
+        \return the text at the offset.
+    */
+    QString textWithBoundary(int offset, TextBoundary boundary, int *startOffset = nullptr, int *endOffset = nullptr) const;
+
     /**
         \brief Set the text of the EditableTextInterface.
 
@@ -590,6 +621,14 @@ public:
     */
     double currentValue() const;
 
+    /**
+        \brief Set the value of the valuator.
+
+        \param value the value to set.
+        \return true on success and false on error.
+    */
+    bool setCurrentValue(const double value);
+
     /**
         \brief Returns the selection of accessible objects.
     */
@@ -673,6 +712,13 @@ public:
     /// Returns if the AccessibleObject is a single line text edit
     bool isSingleLine() const;
 
+    /**
+      \brief Return a string representing states of this object.
+
+      This is useful for debugging applications.
+    */
+    QString stateString() const;
+
     /*
      * \internal
      * \brief isTransient marks an object as being unreliable in that it can quickly disappear or change
@@ -721,10 +767,11 @@ private:
 #ifndef QT_NO_DEBUG_STREAM
     friend QDebug QAccessibleClient::operator<<(QDebug, const AccessibleObject &);
 #endif
-    friend unsigned int ::qHash(const AccessibleObject& object);
+    friend uint qHash(const QAccessibleClient::AccessibleObject& object) {
+        return qHash(object.d);
+    }
 };
 
-
 }
 
 Q_DECLARE_METATYPE(QAccessibleClient::AccessibleObject)
